Learn R Programming

kcirt (version 0.6.0)

ikcirt.rndData1: Random Data

Description

Generate a random realization of a minimally defined k-Cube Thurstonian IRT Model. Probably no need for user to call; called by kcirt.sim.

Usage

ikcirt.rndData1(N, qTypes, mxDelta, ns)

Arguments

N
Number of observational units.
qTypes
Is a question to be fully ranked or most/least format. A character vector whose length is the number of blocks. Each element in 'R', 'M'.
mxDelta
Delta matrix.
ns
Response dimensions. A vector of length equal to the number of questions, each element giving the number of items in the question.

Value

Ranked Data matrix.

Examples

Run this code
constructMap.ls <- list(
c(1,2),
c(2,3),
c(1,3)
)

qTypes <- rep("R", length(constructMap.ls))

mod <- kcirt.model(constructMap.ls=constructMap.ls, qTypes=qTypes, mxLambda=NULL)

N <- 50
set.seed(99999)
mod <- kcirt.sim(model=mod, N=N)

ikcirt.rndData1(N=N, qTypes=qTypes, mxDelta=mod$mxDelta, ns=mod$ns)

Run the code above in your browser using DataLab