Rdocumentation
powered by
Learn R Programming
kcirt (version 0.6.0)
ikcirt.Ustar2data: Convert
U
* to Data
Description
Convert the non-differenced latent responses to Data. Probably no need for user to call; called by
kcirt.sim
.
Usage
ikcirt.Ustar2data(Ustar, qTypes, mxDelta, ns)
Arguments
Ustar
Non-differenced latent responses matrix.
qTypes
Is a question to be fully ranked or most/least format. A character vector whose length is the number of blocks. Each element in
{'R', 'M'}
.
mxDelta
System Delta matrix, elements in
{-1,0,1}
.
ns
Response dimensions. A vector of length equal to the number of questions, each element giving the number of items in the question.
Value
Ranked Data matrix.