| Package: |
| kcirt |
| Type: |
| Package |
| Version: |
| 0.6.0 |
| Date: |
| 2014-04-22 |
| License: |
| GPL (>= 2) |
kcirt.model to define a k-Cube Thurstonian IRT model. The function kcirt.sim generates a random realization. The function kcirt.fitEE uses an expectation-expectation volley to approximately locate mu and Lambda and predict the states, Eta. The function kcirt.fitMSS makes use of metaheuristic stochastic search to further refine the predictions/estimates.The system of interest is defined as
$y$$_i$* = $\Delta$ $\mu$ + $\Delta$ $\Lambda$ $S$ $\eta$$_i$ + $\Delta$ $\epsilon$$_i$
$y$ = 1, if $y$* > 0
$y$ = 0, otherwise
$Y$ = ($y_1$, $y_2$, ..., $y_N$)
where
$y$$_i$ is the (column) response vector for observation $i$.
$\Delta$ is the Delta matrix.
$\mu$ is the column vector of item means (aka, 'utilities').
$\Lambda$ is the hyperparameter matrix (aka, 'loadings').
$S$ is the Slot matrix.
$\eta$$_i$ is the row vector of latent states (aka, 'constructs', or 'scales') for observation $i$.
$\epsilon$$_i$ ~ $N[0, \Sigma_s]$ is a column vector of system shocks for observation $i$.